Learn R Programming

gatoRs (version 1.0.0)

basis_clean: Basis Cleaning - Removes records with certain record basis

Description

The basis_clean() function removes records based on basisOfRecord column.

Usage

basis_clean(df, basis.list = NA, basis.of.record = "basisOfRecord")

Value

Returns a data frame with records of desired record basis.

Arguments

df

Data frame of occurrence records returned from gators_download().

basis.list

A list of basis to keep. If a list is not supplied, the filter will be interactive and users must respond to the function.

basis.of.record

Default = "basisOfRecord". The name of the basis of record column in the data frame.

Details

This function requires no additional packages.

Examples

Run this code
cleaned_data <- basis_clean(data, basis.list = c("Preserved Specimen","Physical specimen"))

Run the code above in your browser using DataLab