Learn R Programming

gatoRs (version 1.0.0)

fix_names: Used in gators_download() - Fix taxonomic name capitalization

Description

The fix_names() function fixes the capitalization of species names in the data frame provided to align with accepted capitalization standards.

Usage

fix_names(df, scientific.name = "scientificName")

Value

Returns df with fixed capitalization in name column.

Arguments

df

Data frame with name column to be fixed.

scientific.name

Default = "scientificName". The name of the scientific name column in the data frame.

Details

This function uses the fixAfterPeriod() function. This function requires package stringr.

Examples

Run this code
fixed_data <- fix_names(data)

Run the code above in your browser using DataLab