Learn R Programming

gatoRs (version 1.0.0)

get_idigbio: Used in gators_download() - Download data from Integrated Digitized Biocollections

Description

The get_idigbio() function queries iDigBio for your desired species. Limited to 100,000 record downloads.

Usage

get_idigbio(synonyms.list, limit = 1e+05)

Value

A data frame with desired columns from iDigBio.

Arguments

synonyms.list

A list of affiliated names for your query.

limit

Default = 100,000 (maximum). Set limit to the number of records requested for each element in synonyms.list.

Details

This function uses the correct_class() function. This function requires the packages ridigbio, magrittr, and dplyr.

Examples

Run this code
df <- get_idigbio(c("Galax urceolata", "Galax aphylla"), limit = 100)

Run the code above in your browser using DataLab