Learn R Programming

gatoRs (version 1.0.0)

needed_records: Identify Missing Information - Find records with redacted or missing data

Description

The needed_records() function identifies records with flags. This indicates that information is withheld from these records due to endangered species status, for example. Accessing this information may require a permit. Or, these records can be removed from the data set.

Usage

needed_records(df, info.withheld = "informationWithheld")

Value

A data frame with only records for which locality was flagged.

Arguments

df

A data frame downloaded with gators_download().

info.withheld

Default = "informationWithheld". The name of the information withheld column in the data frame.

Details

This function requires no additional packages.

Examples

Run this code
need_info <- needed_records(data)

Run the code above in your browser using DataLab