Learn R Programming

gatoRs (version 1.0.0)

remove_skewed: Used in basic_locality_clean() - Removed skewed locality

Description

The remove_skewed() function identifies and removes records where locality has been skewed.

Usage

remove_skewed(df, info.withheld = "informationWithheld")

Value

A data frame with records remove only records for which locality was skewed.

Arguments

df

A data frame downloaded with gators_download().

info.withheld

Default = "informationWithheld". The name of the information withheld column in the data frame.

Details

This function requires no additional packages.

Examples

Run this code
cleaned_data <- remove_skewed(data)

Run the code above in your browser using DataLab