powered by
The basis_clean() function removes records based on basisOfRecord column.
basis_clean()
basis_clean(df, basis.list = NA, basis.of.record = "basisOfRecord")
Returns a data frame with records of desired record basis.
Data frame of occurrence records returned from gators_download().
gators_download()
A list of basis to keep. If a list is not supplied, the filter will be interactive and users must respond to the function.
Default = "basisOfRecord". The name of the basis of record column in the data frame.
This function requires no additional packages.
cleaned_data <- basis_clean(data, basis.list = c("Preserved Specimen","Physical specimen"))
Run the code above in your browser using DataLab