Learn R Programming

gatoRs (version 1.0.0)

citation_bellow: Cite Data - Get GBIF citations

Description

The citation_bellow function retrieves and returns the citation information for the data provided by GBIF in a data frame.

Usage

citation_bellow(df, id = "ID", aggregator = "aggregator")

Value

Returns a list with citation information for the GBIF data downloaded.

Arguments

df

Data frame of occurrence records returned from gators_download().

id

Default = "ID". The name of the id column in the data frame, which contains unique IDs defined from GBIF or iDigBio.

aggregator

Default = "aggregator". The name of the column in the data frame that identifies the aggregator that provided the record.

Details

This function requires the rgbif package.

Examples

Run this code
# \donttest{
citations <- citation_bellow(data)
# }

Run the code above in your browser using DataLab