powered by
The citation_bellow function retrieves and returns the citation information for the data provided by GBIF in a data frame.
citation_bellow
citation_bellow(df, id = "ID", aggregator = "aggregator")
Returns a list with citation information for the GBIF data downloaded.
Data frame of occurrence records returned from gators_download().
gators_download()
Default = "ID". The name of the id column in the data frame, which contains unique IDs defined from GBIF or iDigBio.
Default = "aggregator". The name of the column in the data frame that identifies the aggregator that provided the record.
This function requires the rgbif package.
# \donttest{ citations <- citation_bellow(data) # }
Run the code above in your browser using DataLab