powered by
The fix_names() function fixes the capitalization of species names in the data frame provided to align with accepted capitalization standards.
fix_names()
fix_names(df, scientific.name = "scientificName")
Returns df with fixed capitalization in name column.
Data frame with name column to be fixed.
Default = "scientificName". The name of the scientific name column in the data frame.
This function uses the fixAfterPeriod() function. This function requires package stringr.
fixAfterPeriod()
fixed_data <- fix_names(data)
Run the code above in your browser using DataLab