need_to_georeference: Identify Missing Information - Find records which lack coordinate information
Description
The need_to_georeference() function allows you to find records that are missing coordinates
but contain locality information. These records can then be manually georeferenced.
Usage
need_to_georeference(
df,
longitude = "longitude",
latitude = "latitude",
locality = "locality"
)
Value
Returns a data frame of the points that need to be georeferenced.
For more information about this data frame, see gators_download().
Arguments
- df
A data frame downloaded with gators_download().
- longitude
Default = "longitude". The name of the longitude column in the data frame.
- latitude
Default = "latitude". The name of the latitude column in the data frame.
- locality
Default = "locality". The name of the locality column in the data frame.
Details
This function requires no additional packages.
Examples
Run this codeneed_coords <- need_to_georeference(data)
Run the code above in your browser using DataLab