powered by
The remove_skewed() function identifies and removes records where locality has been skewed.
remove_skewed()
remove_skewed(df, info.withheld = "informationWithheld")
A data frame with records remove only records for which locality was skewed.
A data frame downloaded with gators_download().
gators_download()
Default = "informationWithheld". The name of the information withheld column in the data frame.
This function requires no additional packages.
cleaned_data <- remove_skewed(data)
Run the code above in your browser using DataLab