Learn R Programming

gatoRs (version 1.0.0)

suppress_output: Suppress print statements and messages

Description

The suppress_output() function suppresses print statements and messages from a function. This does not suppress warnings or errors.

Usage

suppress_output(input)

Value

output Output is the output of the passed function call.

Arguments

input

Details

This function requires no additional packages.