powered by
The suppress_output() function suppresses print statements and messages from a function. This does not suppress warnings or errors.
suppress_output()
suppress_output(input)
output Output is the output of the passed function call.
This function requires no additional packages.